@@ -53,6 +53,7 @@ import static com.openexchange.calendar.printing.CPServiceRegistry.getInstance;
 import com.openexchange.ajax.osgi.AbstractSessionServletActivator;
 import com.openexchange.calendar.printing.CPServlet;
 import com.openexchange.calendar.printing.preferences.CalendarPrintingEnabled;
+import com.openexchange.calendar.printing.templating.CalendarTemplateHelperFactory;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.group.GroupService;
@@ -63,6 +64,7 @@ import com.openexchange.html.HtmlService;
 import com.openexchange.i18n.I18nService;
 import com.openexchange.osgi.RegistryCustomizer;
 import com.openexchange.resource.ResourceService;
+import com.openexchange.templating.TemplateHelperFactory;
 import com.openexchange.templating.TemplateService;
 import com.openexchange.user.UserService;
 
@@ -88,15 +90,7 @@ public class CalendarPrintingActivator extends AbstractSessionServletActivator {
         openTrackers();
         register();
         registerService(PreferencesItemService.class, new CalendarPrintingEnabled());
-    }
-
-    @Override
-    protected void stopBundle() throws Exception {
-        try {
-            super.stopBundle();
-        } finally {
-            CPServlet.setServiceLookup(null);
-        }
+        registerService(TemplateHelperFactory.class, new CalendarTemplateHelperFactory(this));
     }
 
     private void register() {
@@ -108,7 +102,9 @@ public class CalendarPrintingActivator extends AbstractSessionServletActivator {
             return;
         }
 
-        CPServlet.setServiceLookup(this);
+        CPServlet.setTemplateService(templates);
+        CPServlet.setAppointmentSqlFactoryService(appointmentSqlFactory);
+        CPServlet.setCalendarTools(collectionService);
 
         registerSessionServlet(getService(DispatcherPrefixService.class).getPrefix()+"printCalendar", new CPServlet());
     }
